@@ -1,5 +1,6 @@
-use strictures;
-use lib 'lib';
+use strict;
+use warnings;
+
 {
   package BaseClass;
   use Moo;
